/*
 * Copyright 2024 ETSI
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holder nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package fr.mines_stetienne.ci.saref.checkers;

import java.io.File;
import java.io.IOException;

import fr.mines_stetienne.ci.saref.SAREFPipelineException;
import fr.mines_stetienne.ci.saref.managers.RepositoryManager;

/**
 * Checks TS 103 673 Clause 10.2: Reference ontology pattern documentation and specification.
 * 
 */
public class Clause_10_2_Checker extends AbstractClauseChecker {

	private enum MESSAGE {
		ioexception, missing, one
	}

	public Clause_10_2_Checker(RepositoryManager repositoryManager) {
		super(repositoryManager, Clause_10_2_Checker.class);
	}

	@Override
	public void checkClause() throws SAREFPipelineException {
		String patternDir =  "patterns";
		File dir = new File(repository.getDirectory(), patternDir);
		if (!dir.isDirectory()) {
			if (dir.list().length < 1) {
				log(getMessage(MESSAGE.one));
				logWarning(getMessage(Clause_10_2_Checker.MESSAGE.missing));
			}
			try {
				String[] lines = {"# empty"};	// create empty file.
				CreateFileInDirectoryWithContents(patternDir, "pattern.ttl", lines);
			} catch (IOException ex) {
				logError(getMessage(Clause_10_2_Checker.MESSAGE.ioexception));
			}
		}
// Unable to verify pattern files.
	}
}
